@@ -9,11 +9,12 @@
     Released under the GNU Public Licence, Version 2.
 */
 
-#define VERSION "2.3.7"
+#define VERSION "2.4.1"
 
 #include "ksymoops.h"
 #include <ctype.h>
 #include <errno.h>
+#include <getopt.h>
 #include <malloc.h>
 #include <stdlib.h>
 #include <string.h>
@@ -56,26 +57,26 @@ static void usage(void)
 {
     printf("Version " VERSION "\n");
     printf("usage: %s\n", prefix);
-    printf("\t\t[-v vmlinux]\tWhere to read vmlinux\n"
-	   "\t\t[-V]\t\tNo vmlinux is available\n"
-	   "\t\t[-k ksyms]\tWhere to read ksyms\n"
-	   "\t\t[-K]\t\tNo ksyms is available\n"
-	   "\t\t[-l lsmod]\tWhere to read lsmod\n"
-	   "\t\t[-L]\t\tNo lsmod is available\n"
-	   "\t\t[-o object_dir]\tDirectory containing modules\n"
-	   "\t\t[-O]\t\tNo modules is available\n"
-	   "\t\t[-m system.map]\tWhere to read System.map\n"
-	   "\t\t[-M]\t\tNo System.map is available\n"
-	   "\t\t[-s save.map]\tSave consolidated map\n"
-	   "\t\t[-S]\t\tShort or long lines toggle\n"
-	   "\t\t[-e]\t\tToggle endianess of code bytes\n"
-	   "\t\t[-x]\t\tHex or decimal toggle\n"
-	   "\t\t[-1]\t\tOne shot toggle (exit after first Oops)\n"
-	   "\t\t[-d]\t\tIncrease debug level by 1\n"
-	   "\t\t[-h]\t\tPrint help text\n"
-	   "\t\t[-t target]\tTarget of oops log\n"
-	   "\t\t[-a arch]\tArchitecture of oops log\n"
-	   "\t\t<Oops.file\tOops report to decode\n"
+    printf("\t[-v vmlinux] [--vmlinux=vmlinux]\n\t\t\t\t\tWhere to read vmlinux\n"
+	   "\t[-V] [--no-vmlinux]\t\tNo vmlinux is available\n"
+	   "\t[-k ksyms] [--ksyms=ksyms]\tWhere to read ksyms\n"
+	   "\t[-K] [--no-ksyms]\t\tNo ksyms is available\n"
+	   "\t[-l lsmod] [--lsmod=lsmod]\tWhere to read lsmod\n"
+	   "\t[-L] [--no-lsmod]\t\tNo lsmod is available\n"
+	   "\t[-o object] [--object=object]\tDirectory containing modules or an\n\t\t\t\t\tindividual object name\n"
+	   "\t[-O] [--no-object]\t\tNo objects are available\n"
+	   "\t[-m system.map] [--system-map=system.map]\n\t\t\t\t\tWhere to read System.map\n"
+	   "\t[-M] [--no-system-map]\t\tNo System.map is available\n"
+	   "\t[-s save.map] [--save-map=save.map]\n\t\t\t\t\tSave consolidated map\n"
+	   "\t[-S] [--short-lines]\t\tShort or long lines toggle\n"
+	   "\t[-e] [--endian-swap]\t\tToggle endianess of code bytes\n"
+	   "\t[-x] [--hex]\t\t\tHex or decimal toggle\n"
+	   "\t[-1] [--one-shot]\t\tOne shot toggle (exit after first Oops)\n"
+	   "\t[-d] [--debug]\t\t\tIncrease debug level by 1\n"
+	   "\t[-h] [--help]\t\t\tPrint help text\n"
+	   "\t[-t target] [--target=target]\tTarget of oops log\n"
+	   "\t[-a architecture] [--architecture=architecture]\n\t\t\t\t\tArchitecture of oops log\n"
+	   "\t< Oops.file\t\t\tOops report to decode\n"
 	   "\n"
 	   "\t\tAll flags can occur more than once.  With the exception "
 		"of -o\n"
@@ -96,7 +97,7 @@ static void usage(void)
 	   "\t\tdirectory and its subdirectories are assumed to be "
 		"modules.\n"
 	   "\n"
-	   "\t\tIf any of the vmlinux, object_dir, ksyms or system.map "
+	   "\t\tIf any of the vmlinux, object, ksyms or system.map "
 		"options\n"
 	   "\t\tcontain the string *r (*m, *n, *s) then it is replaced "
 		"at run\n"
@@ -154,8 +155,8 @@ static void multi_opt(int specl, int specu, char type, const char *using)
 	if (using) {
 	    WARNING_M("-%c %s", type, using);
 	    if (type == 'o')
-		WARNING_M(" ...");
-	    WARNING_E("'");
+		WARNING_M("%s", " ...");
+	    WARNING_E("%s", "'");
 	}
 	else
 	    WARNING_E("-%c'", toupper(type));
@@ -243,18 +244,41 @@ static void spec_or_default(int spec, int *some_spec) {
 static void parse(int argc, char **argv, struct options *options, int *spec_h)
 {
     int spec_v = 0, spec_V = 0,
-        spec_o = 0, spec_O = 0,
-        spec_k = 0, spec_K = 0,
-        spec_l = 0, spec_L = 0,
-        spec_m = 0, spec_M = 0,
-        spec_s = 0;
+	spec_o = 0, spec_O = 0,
+	spec_k = 0, spec_K = 0,
+	spec_l = 0, spec_L = 0,
+	spec_m = 0, spec_M = 0,
+	spec_s = 0;
     struct utsname buf;
     static char const procname[] = "parse";
+    struct option long_opts[] = {
+	{"vmlinux", 1, 0, 'v'},
+	{"no-vmlinux", 0, 0, 'V'},
+	{"ksyms", 1, 0, 'k'},
+	{"no-ksyms", 0, 0, 'K'},
+	{"lsmod", 1, 0, 'l'},
+	{"no-lsmod", 0, 0, 'L'},
+	{"object", 1, 0, 'o'},
+	{"no-object", 0, 0, 'O'},
+	{"system-map", 1, 0, 'm'},
+	{"no-system-map", 0, 0, 'M'},
+	{"save-map", 1, 0, 's'},
+	{"short-lines", 0, 0, 'S'},
+	{"endian-swap", 0, 0, 'e'},
+	{"hex", 0, 0, 'x'},
+	{"one-shot", 0, 0, '1'},
+	{"debug", 0, 0, 'd'},
+	{"help", 0, 0, 'h'},
+	{"target", 1, 0, 't'},
+	{"architecture", 1, 0, 'a'},
+	{0, 0, 0, 0}
+    };
 
     int c, i, some_spec = 0;
     char *p, *before;
 
-    while ((c = getopt(argc, argv, "v:Vk:Kl:Lo:Om:Ms:e1xShdt:a:")) != EOF) {
+    while ((c = getopt_long(argc, argv, "v:Vk:Kl:Lo:Om:Ms:e1xShdt:a:",
+	    long_opts, NULL)) != EOF) {
 	if (c != 'd')
 	    DEBUG(1, "'%c' '%s'", c, optarg);
 	switch(c) {
@@ -455,7 +479,7 @@ static void parse(int argc, char **argv, struct options *options, int *spec_h)
     if (!some_spec) {
 	/* special warning, no procname */
 	++warnings;
-	WARNING_E(
+	WARNING_E("%s", 
 "Warning: You did not tell me where to find symbol information.  I will\n"
 "assume that the log matches the kernel and modules that are running\n"
 "right now and I'll use the default options above for symbol resolution.\n"
@@ -590,11 +614,11 @@ int main(int argc, char **argv)
      * unless there is a problem.
      */
     if (sizeof(U16) != 2)
-	FATAL("sizeof(U16) != 2");
+	FATAL("%s", "sizeof(U16) != 2");
     if (sizeof(U32) != 4)
-	FATAL("sizeof(U32) != 4");
+	FATAL("%s", "sizeof(U32) != 4");
     if (sizeof(U64) != 8)
-	FATAL("sizeof(U64) != 8");
+	FATAL("%s", "sizeof(U64) != 8");
 
     parse(argc, argv, &options, &spec_h);
 
@@ -604,7 +628,7 @@ int main(int argc, char **argv)
     bfd_init();
 
     if ((options.target && strcmp(options.target, "?") == 0) ||
-        (options.architecture && strcmp(options.architecture, "?") == 0)) {
+	(options.architecture && strcmp(options.architecture, "?") == 0)) {
 	print_available_ta(&options);
 	return(0);  /* just the available target/architecture */
     }
