@@ -13,56 +13,56 @@
 
 #define FATAL(format, args...) \
     do { \
-	printf("Fatal Error (%s): " format "\n", procname , ##args); \
+	printf("Fatal Error (%s): " format "\n", procname, args); \
 	exit(2); \
        } while(0)
 
 #define ERROR(format, args...) \
     do { \
-	printf("Error (%s): " format "\n", procname , ##args); \
+	printf("Error (%s): " format "\n", procname, args); \
 	++errors; \
        } while(0)
 
 #define WARNING(format, args...) \
     do { \
-	 printf("Warning (%s): " format "\n", procname , ##args); \
+	 printf("Warning (%s): " format "\n", procname, args); \
 	 ++warnings; \
        } while(0)
 
 #define WARNING_S(format, args...) \
     do { \
-	 printf("Warning (%s): " format, procname , ##args); \
+	 printf("Warning (%s): " format, procname, args); \
 	 ++warnings; \
        } while(0)
 
 #define WARNING_M(format, args...) \
     do { \
-	 printf(format , ##args); \
+	 printf(format, args); \
        } while(0)
 
 #define WARNING_E(format, args...) \
     do { \
-	 printf(format "\n" , ##args); \
+	 printf(format "\n", args); \
        } while(0)
 
 #define DEBUG(level, format, args...) \
     do { \
-        if(debug >= level) { \
-	    printf("DEBUG (%s): " format "\n", procname , ##args); \
+	if(debug >= level) { \
+	    printf("DEBUG (%s): " format "\n", procname, args); \
 	} \
        } while(0)
 
 #define DEBUG_S(level, format, args...) \
     do { \
-        if(debug >= level) { \
-	    printf("DEBUG (%s): " format, procname , ##args); \
+	if(debug >= level) { \
+	    printf("DEBUG (%s): " format, procname, args); \
 	} \
        } while(0)
 
 #define DEBUG_E(level, format, args...) \
     do { \
-        if(debug >= level) { \
-	    printf(format "\n" , ##args); \
+	if(debug >= level) { \
+	    printf(format "\n", args); \
 	} \
        } while(0)
 
