@@ -66,11 +66,11 @@ void read_system_map(const char *system_map)
     }
     else {
 	WARNING("no kernel symbols in System.map, is %s a valid System.map "
-	        "file?", system_map);
+		"file?", system_map);
     }
 
     DEBUG(2, "%s used %d out of %d entries", ss_system_map.source,
-        ss_system_map.used, ss_system_map.alloc);
+	ss_system_map.used, ss_system_map.alloc);
 }
 
 /* Compare two maps, all symbols in the first should appear in the second. */
@@ -86,7 +86,7 @@ void compare_maps(const SYMBOL_SET *ss1, const SYMBOL_SET *ss2,
 	return;
 
     DEBUG(2, "%s vs %s, %s takes precedence", ss1->source, ss2->source,
-        precedence == 1 ? ss1->source : ss2->source);
+	precedence == 1 ? ss1->source : ss2->source);
 
     for (i = 0; i < ss1->used; ++i) {
 	s1 = ss1->symbol+i;
@@ -118,13 +118,13 @@ void compare_maps(const SYMBOL_SET *ss1, const SYMBOL_SET *ss2,
 	     * boot time so silently ignore any mismatches on these symbols.
 	     */
 	    if (strncmp(s1->name, "___", 3) == 0 &&
-	        s1->name[4] == '_' &&
-	        (s1->name[3] == 'f' ||
-	         s1->name[3] == 'b' ||
-	         s1->name[3] == 's' ||
-	         s1->name[3] == 'a' ||
-	         s1->name[3] == 'h' ||
-	         s1->name[3] == 'i'))
+		s1->name[4] == '_' &&
+		(s1->name[3] == 'f' ||
+		 s1->name[3] == 'b' ||
+		 s1->name[3] == 's' ||
+		 s1->name[3] == 'a' ||
+		 s1->name[3] == 'h' ||
+		 s1->name[3] == 'i'))
 		continue;
 	    WARNING("mismatch on symbol %s %c, %s says %llx, %s says %llx.  "
 		    "Ignoring %s entry",
@@ -149,16 +149,16 @@ static void append_map(SYMBOL_SET *symbol, const SYMBOL_SET *related, char *modu
 	return;
     DEBUG_S(2, "%s to %s", related->source, symbol->source);
     if (module)
-        DEBUG_E(2, " [%s]", module);
+	DEBUG_E(2, " [%s]", module);
     else
-        DEBUG_E(2, "");
+	DEBUG_E(2, "%s", "");
 
     for (i = 0; i < related->used; ++i) {
 	s = related->symbol+i;
 	if (s->keep) {
 	    symnum = add_symbol_n(symbol, s->address, s->type, 1, s->name);
 	    (symbol->symbol)[symnum].module = module;
-        }
+	}
     }
 }
 
@@ -170,7 +170,7 @@ void merge_maps(const char *save_system_map, const OPTIONS *options)
     FILE *f;
     static char const procname[] = "merge_maps";
 
-    DEBUG(1, "");
+    DEBUG(1, "%s", "");
 
     /* Using_Versions only appears in ksyms, copy to other tables */
     if ((s = find_symbol_name(&ss_ksyms_base,
@@ -209,7 +209,7 @@ void merge_maps(const char *save_system_map, const OPTIONS *options)
 		ss_ksyms_module[i]),
 	    ss_ksyms_module[i]->source);
     if (!ss_merged.used)
-	WARNING("no symbols in merged map");
+	WARNING("%s", "no symbols in merged map");
 
     /* drop duplicates, type a (registers), type G (modutils assist) and 
      * gcc2_compiled.
@@ -244,7 +244,7 @@ void merge_maps(const char *save_system_map, const OPTIONS *options)
 		    format_address(s->address, options),
 		    s->type, s->name);
 		    if (s->module)
-		        fprintf(f, "\t[%s]", s->module);
+			fprintf(f, "\t[%s]", s->module);
 		    fprintf(f, "\n");
 	    }
 	    ++s;
