@@ -35,7 +35,7 @@ static void Oops_open_input_bfd(char **me, bfd **ibfd, const OPTIONS *options)
 
     if (!*ibfd && !(*ibfd = bfd_openr(*me, NULL))) {
 	Oops_bfd_perror(*me);
-	FATAL("giving up");
+	FATAL("%s", "giving up");
     }
 
     if (!bfd_check_format_matches(*ibfd, bfd_object, &matches)) {
@@ -48,7 +48,7 @@ static void Oops_open_input_bfd(char **me, bfd **ibfd, const OPTIONS *options)
 	    printf("\n");
 	    free(matches);
 	}
-	FATAL("giving up");
+	FATAL("%s", "giving up");
     }
 }
 
@@ -300,7 +300,7 @@ static void Oops_decode_one(SYMBOL_SET *ss, const char *line, addr_t eip,
 	eip_relative = hexstring(string[4]);
 	if (errno) {
 	    ERROR("Invalid hex value in objdump line, treated as zero - '%s'\n"
-	          "objdump line '%s'", string[4], line);
+		  "objdump line '%s'", string[4], line);
 	    perror(prefix);
 	    eip_relative = 0;
 	}
@@ -350,7 +350,7 @@ static int Oops_code_values(const unsigned char* code_text, unsigned char *code,
      * The first character is nonblank.
      */
     if (!isxdigit(*code_text)) {
-	WARNING("Code looks like message, not hex digits.  "
+	WARNING("%s", "Code looks like message, not hex digits.  "
 	    "No disassembly attempted.");
 	return(0);
     }
@@ -369,7 +369,7 @@ static int Oops_code_values(const unsigned char* code_text, unsigned char *code,
 	      "[)>]?"
 	      " *"
 	    ")"
-	    "|(Bad EIP value)"		/* 4 */
+	    "|(Bad .*)"			/* 4 */
 	    ,
 	REG_NEWLINE|REG_EXTENDED|REG_ICASE,
 	&re_Oops_code_value_pmatch);
@@ -387,7 +387,7 @@ static int Oops_code_values(const unsigned char* code_text, unsigned char *code,
 	value = hexstring(string[3]);
 	if (errno) {
 	    ERROR("Invalid hex value in code_value line, treated as zero - "
-	          "'%s'\ncode_value line '%s'", string[3], code_text);
+		  "'%s'\ncode_value line '%s'", string[3], code_text);
 	    perror(prefix);
 	    value = 0;
 	}
@@ -509,7 +509,7 @@ static void Oops_set_eip(const char *value, addr_t *eip, SYMBOL_SET *ss,
     snprintf(eip_name, sizeof(eip_name), ">>%-3s;",
 	 Oops_arch_to_eip(options));
     while ((p = strstr(eip_name, " ;")))
-        strncpy(p, "; ", 2);
+	strncpy(p, "; ", 2);
     *eip = Oops_truncate_address(*eip, options);
     add_symbol_n(ss, *eip, 'E', 1, eip_name);
 }
@@ -528,9 +528,9 @@ static int         s390_reg_num = -1;
 static addr_t Oops_truncate_address(addr_t address, const OPTIONS *options)
 {
     if (options->address_bits == 32 ||
-        (options->target && (
+	(options->target && (
 	 strstr(options->target, "i370") ||
-         strstr(options->target, "s390")))) {
+	 strstr(options->target, "s390")))) {
 	U32 u32 = address;
 	if (strstr(options->target, "i370") ||
 	    strstr(options->target, "s390"))
@@ -561,7 +561,7 @@ static const char *Oops_arch_to_eip(const OPTIONS *options)
     if (strstr(options->target, "powerpc"))
 	return("NIP");
     if (strstr(options->target, "i370") ||
-        strstr(options->target, "s390"))
+	strstr(options->target, "s390"))
 	return("PSW");
     if (strstr(options->target, "ia64"))
 	return("IP");
@@ -1006,8 +1006,8 @@ static char *Oops_i370_psw(const char *line, char ***string, int string_max)
 
 /* Set the i370 PSW from the PSW line */
 static void Oops_set_i370_psw(const char *value, SYMBOL_SET *ss,
-                              const char *me, const bfd *ibfd,
-                              OPTIONS *options)
+			      const char *me, const bfd *ibfd,
+			      OPTIONS *options)
 {
     static const char procname[] = "Oops_set_i370_psw";
     addr_t PSW;
@@ -1055,7 +1055,7 @@ static char *Oops_s390_psw(const char *line, char ***string, int string_max)
 
 /* No need for Oops_set_s390_psw, can use Oops_set_i370_psw for both */
 #define Oops_set_s390_psw(line, string, me, ibfd, options) \
-        Oops_set_i370_psw(line, string, me, ibfd, options)
+	Oops_set_i370_psw(line, string, me, ibfd, options)
 
 /* Look for the Trace multilines :(.  Returns start of addresses. */
 static const char *Oops_trace(const char *line)
@@ -1669,24 +1669,24 @@ static int Oops_print(const char *line, const char **text, char ***string,
 	stack_line = 0;
     /* Trace lines */
     if (!MATCHED(4) && !MATCHED(5) && !MATCHED(6) && !MATCHED(9) &&
-        !MATCHED(10) && !MATCHED(11) && !MATCHED(12) && !MATCHED(13) &&
+	!MATCHED(10) && !MATCHED(11) && !MATCHED(12) && !MATCHED(13) &&
 	!MATCHED(15) && !MATCHED(16) && !MATCHED(17) && !MATCHED(19))
 	trace_line = 0;
     else if (MATCHED(4) || MATCHED(5) || MATCHED(9) || MATCHED(10) ||
-        MATCHED(11) || MATCHED(15) || MATCHED(16) || MATCHED(17))
+	MATCHED(11) || MATCHED(15) || MATCHED(16) || MATCHED(17))
 	trace_line = 1;
     else if (trace_line && !MATCHED(4) && !MATCHED(6) && !MATCHED(12) &&
-        !MATCHED(13) && !MATCHED(19))
+	!MATCHED(13) && !MATCHED(19))
 	trace_line = 0;
     if (i == 0) {
 	print = 1;
 	if (MATCHED(4) && !stack_line && !trace_line) {
 	    print = 0;
-	    DEBUG(4, "ambiguous stack/trace line ignored");
+	    DEBUG(4, "%s", "ambiguous stack/trace line ignored");
 	}
 	if ((MATCHED(6) || MATCHED(12) || MATCHED(13)) && !trace_line) {
 	    print = 0;
-	    DEBUG(4, "ambiguous trace line ignored");
+	    DEBUG(4, "%s", "ambiguous trace line ignored");
 	}
     }
     if (print && MATCHED(4)) {
@@ -1707,7 +1707,7 @@ static int Oops_print(const char *line, const char **text, char ***string,
 		print = 0;  /* ignore ambiguous match */
 	}
 	if (!print)
-	    DEBUG(4, "ambiguous start ignored");
+	    DEBUG(4, "%s", "ambiguous start ignored");
     }
     /* delay splitting into strings until we really them */
     if (print && MATCHED(8)) {
@@ -1849,7 +1849,7 @@ static void Oops_decode(const unsigned char* code_text, addr_t eip,
     int size = 0, adjust, lines = 0;
     static char const procname[] = "Oops_decode";
 
-    DEBUG(1, "");
+    DEBUG(1, "%s", "");
     /* text to binary */
     if (!Oops_code_values(code_text, code, &adjust, options))
 	return;
@@ -1883,7 +1883,7 @@ static void Oops_format(const SYMBOL_SET *ss_format, OPTIONS *options)
     char *eye_catcher;
     static const char procname[] = "Oops_format";
 
-    DEBUG(1, "");
+    DEBUG(1, "%s", "");
 
     compare_Version();  /* Oops might have a version one day */
     printf("\n");
@@ -2053,7 +2053,7 @@ int Oops_read(OPTIONS *options)
 	     * Code: line.
 	     */
 	    if (ss_format.used && lineno > lastprint+5) {
-		WARNING("Code line not seen, dumping what data is available");
+		WARNING("%s", "Code line not seen, dumping what data is available");
 		Oops_format(&ss_format, options);
 		ss_free(&ss_format);
 		if (options->one_shot)
@@ -2066,7 +2066,7 @@ int Oops_read(OPTIONS *options)
 		sparc_regdump)
 		;	/* sparc regdump comes *after* code, ignore :( */
 	    else
-		WARNING("Code line not seen, dumping what data is available");
+		WARNING("%s", "Code line not seen, dumping what data is available");
 	    Oops_format(&ss_format, options);
 	    ss_free(&ss_format);
 	    if (options->one_shot)
