@@ -91,7 +91,7 @@ void re_strings(regex_t *preg, const char *text, regmatch_t *pmatch,
 	    /* no match for this sub expression */
 	    free((*string)[i]);
 	    (*string)[i] = NULL;
-	    DEBUG_E(5, " (undef)");
+	    DEBUG_E(5, "%s", " (undef)");
 	}
 	else {
 	    int l = pmatch[i].rm_eo - pmatch[i].rm_so + 1;
